var ResponsiveLayout = (function() {
  // Breakpoints
  const breakpoints = {
    xs: '(max-width: 575px)',
    sm: '(min-width: 576px)',
    md: '(min-width: 768px)',
    lg: '(min-width: 992px)',
    xl: '(min-width: 1200px)',
    xxl: '(min-width: 1400px)'
  };

  const defaultProperties = {
    SectionTitleFontSize: 'sectionTitleFontSize',
    SectionTitleAlign: 'sectionTitleAlign',
    SectionTitleMaxWidth: 'sectionTitleMaxWidth',
    SectionTitleMargin: 'sectionTitleMargin',
    SectionHeight: 'sectionHeight',
    SectionPaddingX: 'sectionPaddingX',
    SectionWidth: 'sectionWidth',
    SectionPaddingTop: 'sectionPaddingTop',
    SectionPaddingBottom: 'sectionPaddingBottom',
  };

  const breakpointsKeys = Object.keys(breakpoints);
  var layoutsRegisterCallbacks = [];
  var layout = {};

  layout.applyProperties = function(element, breakpoint, custom_properties = {}) {
    let all_properties = {...defaultProperties, ...custom_properties}
    let properties = Object.keys(all_properties);
    let bkpIndex = {'xs': 1, 'sm': 2, 'md': 3, 'lg': 4, 'xl': 5, 'xxl': 6};
    let indexBkp = {'1': 'xs', '2': 'sm', '3': 'md', '4': 'lg', '5': 'xl', '6': 'xxl'};

    for (let i = 1; i <= bkpIndex[breakpoint]; i++) {
      properties.forEach((property) => {
        if (getComputedStyle(element).getPropertyValue('--' + indexBkp[i] + property)) {
          element.style.setProperty('--' + all_properties[property], 'var(--' + indexBkp[i] + property + ')');
        }
      })
    }

  }

  layout.layoutsRegister = function(layoutType, callback) {
    let layouts = document.getElementsByClassName(layoutType);
    layoutsRegisterCallbacks.push({layouts: layouts, callback: callback});
  };

  layout.addEvent = function(object, type, callback) {
    if (object == null || typeof(object) == 'undefined') return;
    if (object.addEventListener) {
        object.addEventListener(type, callback, false);
    } else if (object.attachEvent) {
        object.attachEvent("on" + type, callback);
    } else {
        object["on"+type] = callback;
    }
  }

  layout.layoutsCallback = function() {
    let container = document.getElementById('layout-builder');
    if (container !== null) {
      let mq = container.getAttribute('media-query');
      if (mq !== null) {
        breakpointsKeys.forEach((breakpoint) => {
          if (mq === breakpoints[breakpoint]) {
            layoutsRegisterCallbacks.forEach((layoutType)=>{
              layoutType.callback(layoutType.layouts, breakpoint)
            })
          }
        })
      }
      
      if (mq === null) {
        breakpointsKeys.forEach((breakpoint) => {
          let mediaQuery = window.matchMedia(breakpoints[breakpoint])
          if (mediaQuery.matches) {
            layoutsRegisterCallbacks.forEach((layoutType)=>{
              layoutType.callback(layoutType.layouts, breakpoint)
            })
          }
        })
      }
    } else if (container === null) {
      breakpointsKeys.forEach((breakpoint) => {
        let mediaQuery = window.matchMedia(breakpoints[breakpoint])
        if (mediaQuery.matches) {
          layoutsRegisterCallbacks.forEach((layoutType)=>{
            layoutType.callback(layoutType.layouts, breakpoint)
          })
        }
      })
    }

  }
  return layout;
}());

window.ResponsiveLayout = ResponsiveLayout
ResponsiveLayout.addEvent(window, "load", ResponsiveLayout.layoutsCallback)
ResponsiveLayout.addEvent(window, "resize", ResponsiveLayout.layoutsCallback)
Drupal.behaviors.responsiveLayoutCallbacks = {  
  attach: function (context, settings) {    
    ResponsiveLayout.layoutsCallback();
  }
};
